confint.funcSynth: Confidence interval method for funcSynth objects

View source: R/confint_funcsynth.R

confint.funcSynthR Documentation

Confidence interval method for funcSynth objects

Description

Confidence interval method for funcSynth objects

Usage

## S3 method for class 'funcSynth'
confint(object, parm = c("syntheticControl", "gap"), level = 0.95, ...)

Arguments

object

a functional synthetic control object

parm

one (or both) of "syntheticControl", "gap". The former produces a confidence interval for the snythetic control estimate and the latter produces a confidence interval for the effect estimate.

level

level of confidence for the interval

...

not used


abshev/funkySynth documentation built on June 11, 2022, 11:39 p.m.