lintifyData: Function subsets data to a single list unit or "lint".

View source: R/lintify_data.R

lintifyDataR Documentation

Function subsets data to a single list unit or "lint".

Description

Function subsets data to a single list unit or "lint".

Usage

lintifyData(u, y, t, ut, it, prepost, yt)

Arguments

u

unit to subset

y

outcome variable

t

time variable

ut

unit variable

it

intervention variable

prepost

pre or post intervention

yt

selects where to make a list unit for outcome or time


abshev/funkySynth documentation built on June 11, 2022, 11:39 p.m.