listifyData: Converts modular synth object into list format needed for...

View source: R/listify_data.R

listifyDataR Documentation

Converts modular synth object into list format needed for FPCA()

Description

Converts modular synth object into list format needed for FPCA()

Usage

listifyData(mSynth)

Arguments

mSynth

a modular synth object


abshev/funkySynth documentation built on June 11, 2022, 11:39 p.m.