modularSynth: Creates modularSynth object for use in funcSynth()

View source: R/modular_synth.R

modularSynthR Documentation

Creates modularSynth object for use in funcSynth()

Description

Creates modularSynth object for use in funcSynth()

Usage

modularSynth(y, time, unit, intervention, treated)

Arguments

y

Numeric vector of outcome values.

time

Either a numeric vector or vector of class Date, posixlt, or posixct

unit

Character, numeric, or factor variable indicating unit.

intervention

Binary or logical vector indicating whether an i intervention has occurred on any unit at the corresponding time.

treated

Binary or logical variable indicating if a unit is ever treated at any time.


abshev/funkySynth documentation built on June 11, 2022, 11:39 p.m.