solveForWeights: Function that returns weights and determines V matrix if it...

View source: R/solve_for_weights.R

solveForWeightsR Documentation

Function that returns weights and determines V matrix if it is not supplied

Description

Function that returns weights and determines V matrix if it is not supplied

Usage

solveForWeights(
  X0,
  X1,
  Z0 = NULL,
  Z1 = NULL,
  V,
  lambda = NULL,
  margin.ipop = 5e-04,
  sigf.ipop = 5,
  bound.ipop = 10,
  optimMethod = c("Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN", "Brent")
)

Arguments

X0

FPCA score and covariate matrix for controls

X1

FPCA score and covariate matrix for the treatment

Z0

Outcome matrix for the controls

Z1

Outcome matrix for the treatment

V

Matrix specificing importance of FPCA scores and covariates for determining weights.

lambda

numeric vector of variances from FPCA

margin.ipop

how close we get to the constraints; passed to ipop()

sigf.ipop

Precision; passed to ipop()

bound.ipop

Clipping bound for the variables; passed to ipop()

optimMethod

One of "Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN", "Brent"; passed to optim(). See optim() for more information.


abshev/funkySynth documentation built on June 11, 2022, 11:39 p.m.