View source: R/confint_funcsynth.R
| confint.funcSynth | R Documentation |
Confidence interval method for funcSynth objects
## S3 method for class 'funcSynth'
confint(object, parm = c("syntheticControl", "gap"), level = 0.95, ...)
object |
a functional synthetic control object |
parm |
one (or both) of "syntheticControl", "gap". The former produces a confidence interval for the snythetic control estimate and the latter produces a confidence interval for the effect estimate. |
level |
level of confidence for the interval |
... |
not used |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.