| funcSynth | R Documentation |
Functional Synthetic Control Method
funcSynth(
formula,
data,
covariateFunctions = "mean",
cfArgs = NULL,
fpcaOptions = list(pre = list(), post = list()),
V = c("FVE", "minMSE"),
y = NULL,
time = NULL,
unit = NULL,
intervention = NULL,
treated = NULL,
x = NULL,
...
)
formula |
formula |
data |
data |
covariateFunctions |
named list of function names for summarizing covariates. List names should correspond to variable names. Alternatively, instead of a list, a single function may be supplied to be used on all covariates. |
cfArgs |
arguments for the covariate summary function |
fpcaOptions |
options passed to FPCA() |
V |
Either a numeric vector or matrix, or one of "minMSE" for automated selection of V or "FVE" for percent variation explained. |
y |
outcome |
time |
time |
unit |
unit |
intervention |
indicator for intervention |
treated |
indicator for treated |
x |
covariates |
... |
additional arguments passed to ipop() and optim(). |
TODO
funkySynth object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.