| lintifyData | R Documentation |
Function subsets data to a single list unit or "lint".
lintifyData(u, y, t, ut, it, prepost, yt)
u |
unit to subset |
y |
outcome variable |
t |
time variable |
ut |
unit variable |
it |
intervention variable |
prepost |
pre or post intervention |
yt |
selects where to make a list unit for outcome or time |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.