View source: R/modular_synth.R
| modularSynth | R Documentation |
Creates modularSynth object for use in funcSynth()
modularSynth(y, time, unit, intervention, treated)
y |
Numeric vector of outcome values. |
time |
Either a numeric vector or vector of class Date, posixlt, or posixct |
unit |
Character, numeric, or factor variable indicating unit. |
intervention |
Binary or logical vector indicating whether an i intervention has occurred on any unit at the corresponding time. |
treated |
Binary or logical variable indicating if a unit is ever treated at any time. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.